<?php


function istk_portfolio_headline_text() {
	$str = get_bloginfo( 'description' );
	if ( $mod = get_theme_mod( 'istk_portfolio_text' ) ) {
		if ( !empty( $mod['headliner']) ) {
			$str = $mod['headliner'];
		}
	}
	return $str;
}

function istk_portfolio_headliner() {
	$str = istk_portfolio_headline_text();
	if( !empty( $str ) && display_header_text() ) {
		?><div class="headliner">
		<div class="container"><?php echo esc_html( $str ); ?></div>
		</div>
		<?php
	}
}


function istk_portfolio_display_logo( $position = 'header' ) {
	if ( has_custom_logo() ) {
		the_custom_logo();
	} elseif( display_header_text() ) {
		echo '<a href="' . esc_url( home_url() ) . '" class="str"><span>' . esc_html( get_bloginfo( 'name' ) ) . '</span></a>';
	} else {
		echo '<span class="no-header-text">&nbsp;</span>';
	}
}


function istk_portfolio_display_header_info() {
	$mod = get_theme_mod( 'istk_portfolio_contact' );
	$mod_link_contact = get_theme_mod( 'istk_portfolio_link_contact', home_url() . '/contact/' );
	$mod_link_calendar = get_theme_mod( 'istk_portfolio_link_calendar' );
	
	$tel = '';
	$biz_hour = '';
	$calendar_link = '';
	$contact_btn = '';
	
	if ( !empty( $mod['tel_number'] ) ) {
		$tel = '<div class="tel"><address><a href="tel:' . $mod['tel_number'] . '"><span class="dashicons dashicons-phone"></span>' . $mod['tel_number'] . '</a></address></div>';
	}
	if ( !empty( $mod['biz_hour'] ) ) {
		$biz_hour = '<div class="biz-hour"><span class="dashicons dashicons-arrow-right"></span><span class="tag">'
			. esc_html__( 'Open', 'istk-portfolio' ) //営業時間
			. ' : </span><span class="str">' . $mod['biz_hour'] . '</span></div>';
	}
	if ( !empty( $mod_link_calendar ) ) {
		$calendar_link = '<div class="calendar"><span class="dashicons dashicons-arrow-right"></span><a href="' . $mod_link_calendar . '">'
			. esc_html__( 'Calendar', 'istk-portfolio' ) //'営業カレンダー'
			. '</a> <span class="dashicons dashicons-calendar-alt"></span></div>';
	}
	
	
	echo '<div class="l">' . wp_kses_post( $tel . $biz_hour . $calendar_link ) . '</div>';
	if ( !empty( $mod_link_contact ) ) {
		istk_portfolio_button_contact( $mod_link_contact );
	}
	
}

function istk_portfolio_page_header() {
	$str = '';
	
	/*
		ブログポスト／カテゴリ／タグ→「ブログ」
		ポートフォリオ→「イラスト制作例」またはテーマ設定で決めたタイトル
		ニュース→ニュースアーカイブ
		ページ→ページタイトル（親があれば親のタイトル）
		
		アタッチメント→なし
		フロント→なし
	*/
	if ( is_front_page() ) {
		return;
	}
	//ブログインデックスに設定されたページのid
	$blog_index_id = get_option('page_for_posts');
	
	
	$str = '';
	
	if ( ( is_single() || is_archive() ) && !empty( $blog_index_id ) ) {
		$str = '<p><a href="' . esc_url( get_permalink( $blog_index_id ) ) . '">' . get_the_title( $blog_index_id ) . '</a></p>';
		
		
	} elseif ( is_page() ) {
		//ページ
		
		//親ページがあれば親ページのタイトル
		$ancestors = get_post_ancestors( get_post() );
		if ( !empty( $ancestors ) ) {
			$ans_id = array_pop( $ancestors );
			$str = '<p><a href="' . esc_url( get_permalink( $ans_id ) ) . '">' . get_the_title( $ans_id ) . '</a></p>';
		} else {
			$str = '<h1 class="page-title entry-title">' . get_the_title() . '</h1>';
		}
		
		
	} elseif ( is_home() && !empty( $blog_index_id ) ) {
		//ブログホーム
		$str = '<h1 class="archive-title">' . get_the_title( $blog_index_id ) . '</h1>';
		
		
		
	} elseif ( is_search() ) {
		//検索結果
		$str = '<p>' . esc_html__( 'Search', 'istk-portfolio' ) . '</p>';
		
		
		
	} elseif ( is_404() ) {
		//検索結果
		$str = '<h1 class="page-title">404 Not found</h1>';
		
		
		
	}
	
	
	if ( post_type_exists( 'istk_portfolio' ) ) {
		//istk_portfolio用
		$title = esc_html__( 'Portfolio', 'istk-portfolio' ); //なんもない時用
		if ( function_exists( 'istk_add_on_posttype_title' ) ) {
			$title = istk_add_on_posttype_title();
		}
		
		$portfolio_archive_link = get_post_type_archive_link( 'istk_portfolio' );
		if ( !empty( $portfolio_archive_link ) ) {
			if (
				is_singular( 'istk_portfolio' )
				|| is_tax( 'istk_portfolio_category' )
				|| is_tax( 'istk_portfolio_tag' )
			) {
				$str = '<p><a href="' . esc_url( $portfolio_archive_link ) . '">' . $title . '</a></p>';
			} elseif ( is_post_type_archive( 'istk_portfolio' ) ) {
				$str = '<h1 class="archive-title">' . $title . '</h1>';
			}
		}
	}
	
	if ( post_type_exists( 'istk_news' ) ) {
		$news_archive_link = get_post_type_archive_link( 'istk_news' );
		$news_post_type_obj = get_post_type_object( 'istk_news' );
		if ( is_singular( 'istk_news' ) ) {
			if ( !empty( $news_archive_link ) ) {
				$str = '<p><a href="' . esc_url( $news_archive_link ) . '">' . $news_post_type_obj->labels->name . '</a></p>';
			} else {
				$str = '<p>' . $news_post_type_obj->labels->name . '</p>';
			}
		}
		if ( is_post_type_archive( 'istk_news' ) ) {
			$str = '<h1 class="archive-title">' . post_type_archive_title( '', false ) . '</h1>';
		}
	}
	
	if ( !empty( $str ) ) {
		echo '<div class="page-header"><div class="container">' . wp_kses_post( $str ) . '</div></div>';
	}
}








//