<?php

function istk_portfolio_sidebar_condition() {
	if ( is_single() ) {
		if ( is_attachment() ) {
			return false;
		} elseif( 'post' !== get_post_type() ) {
			return false;
		} else {
			return true;
		}
	} elseif ( is_category() ) {
		return true;
	} elseif ( is_home() ) {
		global $wp_query;
		if ( !empty( $wp_query->is_posts_page ) ) {
			return true;
		} else {
			return false;
		}
	} elseif ( is_tag() ) {
		return true;
	} elseif ( is_date() ) {
		return true;
	}
	
	return false;
}
function istk_portfolio_sidebar_condition_define() {
	define( 'ISTK_PORTFOLIO__DISPLAY_SIDEBAR', istk_portfolio_sidebar_condition());
}
add_action( 'wp_head', 'istk_portfolio_sidebar_condition_define' );


function istk_portfolio_the_post_thumbnail_tag( $size = '', $link = '' ) {
	global $post;
	if ( has_post_thumbnail() ) {
		$img_tag = get_the_post_thumbnail( $post->ID, $size );
	} else {
		$img_tag = '<img src="' .  get_stylesheet_directory_uri() . '/assets/images/no-image.png">';
	}
	
	if ( !empty( $link ) ) {
		?><figure class="post-thumbnail"><a href="<?php the_permalink(); ?>"><?php echo wp_kses_post( $img_tag ); ?></a></figure><?php
	} else {
		echo '<figure class="post-thumbnail">' . wp_kses_post( $img_tag ) . '</figure>';
	}
}


function istk_portfolio_copyright() {
	
	$mod = get_theme_mod( 'istk_portfolio_text' );
	if ( !empty( $mod[ 'copyright' ] ) ) {
		$copyright_str = $mod[ 'copyright' ];
	} else {
		$copyright_str = '&copy;' . get_bloginfo( 'name' );
	}
	echo '<div id="copyright" class="container"><p>' . wp_kses_post( $copyright_str ) . '</p></div>';
	
	
	if ( !empty( $mod[ 'reproduce' ] ) ) {
		echo '<div id="about-reproduce" class="container"><p>' . wp_kses_post( $mod[ 'reproduce' ] ) . '</p></div>';
	}
}


function istk_portfolio_credit() {
	if ( is_admin() ) { return; }
	$attr = wp_get_theme();
	?><div id="theme-credit"><a href="<?php echo esc_url( $attr->get( 'AuthorURI' ) ); ?>"><?php echo esc_html( $attr->get( 'Name' ) ); ?></a></div><?php
}

function istk_portfolio_get_blog_name() {
	$blog_index_id = get_option( 'page_for_posts' );
	if( !empty( $blog_index_id ) ) {
		return esc_html( get_the_title( $blog_index_id ) );
	} else {
		return esc_html__( 'Blog', 'istk-portfolio' );
	}
}



function istk_portfolio_pagenate() {
	$array = array(
		'type'	=>	'list',
	);
	
	global $wp_query;
	if ( $wp_query->max_num_pages > 1 ) {
		echo '<div class="paginate_link">';
		echo wp_kses_post( paginate_links( $array ) );
		echo '</div>';
	}
}

function istk_portfolio_link_pages() {
	$list = wp_link_pages(array(
		'before'	=>	'<div class="page-links"><p class="screen-reader-text">' . __( 'Pages:', 'istk-portfolio' ) . '</p><ul class="page-numbers">',
		'after'	=>	'</ul></div>',
		'echo'	=>	0,
	));
	if ( !empty( $list ) ) {
		$list = str_replace( '<a', '<li><a', $list );
		$list = str_replace( '</a>', '</a></li>', $list );
		$list = str_replace( '<span', '<li><span', $list );
		$list = str_replace( '</span>', '</span></li>', $list );
		echo wp_kses_post( $list );
	}
}


function istk_portfolio_pagenate_arg() {
	$array = array(
		'type'	=>	'list',
	);
	return $array;
}




function istk_portfolio_post_date( $flag = '' ) {
	//日付
	global $post;
	//投稿日
	?><div class="post-date">
	<span class="dashicons dashicons-clock" title="<?php esc_attr_e( 'Posted at', 'istk-portfolio' ); ?>"></span><span class="screen-reader-text"><?php esc_html_e( 'Posted at', 'istk-portfolio' ); ?></span>
	<?php
	the_time( get_option( 'date_format' ) );
	
	if ( $flag !== 'nomodified' ) {
		if ( ( is_singular() ) && ( get_the_modified_date() != get_the_date() ) ) {
			//最終更新日
		?>
		<span class="dashicons dashicons-image-rotate" title="<?php esc_attr_e( 'Last updated at', 'istk-portfolio' ); ?>"></span><span class="screen-reader-text"><?php esc_html_e( 'Last updated at', 'istk-portfolio' ); ?></span>
		<?php the_modified_date();
		}
	}
	?>
	</div><?php
}



function istk_portfolio_post_author() {
	//著者
	printf(
		/* translators: 1: SVG icon. 2: Post author, only visible to screen readers. 3: Author link. */
		'<div class="post-author"><a class="icon" href="%3$s">%1$s</a><span class="screen-reader-text">%2$s</span><span class="author vcard"><a class="url fn n" href="%3$s">%4$s</a></span></div>',
		get_avatar( get_the_author_meta( 'ID' ), 32 ),
		esc_html__( 'Posted by', 'istk-portfolio' ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_html( get_the_author() )
	);
}



function istk_portfolio_post_categories() {
	global $post;
	$categories = get_the_category_list();
	if ( !empty( $categories ) ) {
		echo '<div class="post-categories post-tax"><span class="dashicons dashicons-category" title="' . esc_html__( 'Category', 'istk-portfolio' ) . '"></span><span class="screen-reader-text">' . esc_html__( 'Category', 'istk-portfolio' ) . '</span>' . wp_kses_post( $categories ) . '</div>';
	}
}

function istk_portfolio_post_tags() {
	global $post;
	if ( !empty( get_the_tags() ) ) {
		echo '<div class="post-tags post-tax"><span class="dashicons dashicons-tag" title="' . esc_html__( 'Tag', 'istk-portfolio' ) . '"></span><span class="screen-reader-text">' . esc_html__( 'Tag', 'istk-portfolio' ) . '</span>';
		the_tags( '<ul><li>', '</li><li>', '</li></ul>' );
		echo '</div>';
	}
}






function istk_portfolio_frontpage_blog() {
	$the_query = new WP_Query(array(
		'posts_per_page'	=>	get_option( 'posts_per_page' ),
	));
	$post_type_obj = get_post_type_object( 'post' );

	if ( $the_query->have_posts() ) {
		$all_num = $the_query->found_posts;
		
		?><section class="blog"><div class="container">
		<h1><?php echo esc_html( istk_portfolio_get_blog_name() ); ?></h1>
		<div class="content-list-area">

		<?php
		while ( $the_query->have_posts() ) {
			$the_query->the_post();
			get_template_part( 'content/content', 'list' );
		}
		wp_reset_postdata();

		?></div><?php
		
		if ( ( $all_num > get_option( 'posts_per_page' ) ) ) {
			?><div class="wp-block-button is-style-outline aligncenter"><a href="<?php
				echo esc_url( get_permalink( get_option( 'page_for_posts' ) ) );
			?>" class="wp-block-button__link"><?php
				echo esc_html( $post_type_obj->labels->all_items );
			?></a><?php
		}
		?>
		</div></section><?php
	}
}






//